fdf_arena_allocate

Function fdf_arena_allocate 

pub unsafe extern "C" fn fdf_arena_allocate(
    arena: *mut fdf_arena_t,
    bytes: usize,
) -> *mut c_void
Returns a pointer to allocated memory of size |bytes|. The memory is managed by the arena until it is freed by |fdf_arena_free|, or the arena is destroyed once every reference to the arena hss been destroyed using |fdf_arena_drop_ref|.