fdf_arena_drop_ref

Function fdf_arena_drop_ref 

pub unsafe extern "C" fn fdf_arena_drop_ref(arena: *mut fdf_arena_t)
Destroys the reference to the underlying runtime arena object. If there are no more references to the arena, all memory associated with the arena will be freed.