fdf_arena_free

Function fdf_arena_free 

pub unsafe extern "C" fn fdf_arena_free(
    arena: *mut fdf_arena_t,
    ptr: *mut c_void,
)
Hints to the arena that the |ptr| previously allocated by |fdf_arena_allocate| may be reclaimed. Memory is not guaranteed to be reclaimed until |fdf_arena_drop_ref| is invoked. Asserts if the memory is not managed by the arena.