pub unsafe extern "C" fn fdf_channel_cancel_wait(
handle: fdf_handle_t,
) -> zx_status_tExpand description
Cancels any pending callback registered via |fdf_channel_wait_async|.
Whether the wait handler will run depends on whether the dispatcher it was registered with is synchronized or |FDF_CHANNEL_WAIT_OPTION_FORCE_ASYNC_CANCEL| was passed with in |fdf_channel_wait_async|.
If the dispatcher is synchronized and |FDF_CHANNEL_WAIT_OPTION_FORCE_ASYNC_CANCEL| was not passed, this must only be called from a dispatcher thread, and any pending callback will be canceled synchronously.
If the dispatcher is unsynchronized or |FDF_CHANNEL_WAIT_OPTION_FORCE_ASYNC_CANCEL| was passed, the callback will be scheduled to be called with status |ZX_ERR_CANCELED|.
Errors
ZX_ERR_NOT_FOUND: There was no pending wait either because it is currently running (perhaps in a different thread), already scheduled to be run, already completed, or had not been started.