fdf_channel_create

Function fdf_channel_create 

pub unsafe extern "C" fn fdf_channel_create(
    options: u32,
    out0: *mut fdf_handle_t,
    out1: *mut fdf_handle_t,
) -> zx_status_t
Creates a FDF channel, a bi-directional in-process message transport capable of sending arena-managed raw data bytes as well as handles from one side to the other.

Two handles are returned on success, providing access to both sides of the channel. Messages written to one handle may be read from the opposite.

Errors

ZX_ERR_INVALID_ARGS: |out0| or |out1| is an invalid pointer or NULL or |options| is any value other than 0.

ZX_ERR_NO_MEMORY: Failed due to a lack of memory.

ZX_ERR_NO_RESOURCES: No handles are available.