fdf_dispatcher_destroy

Function fdf_dispatcher_destroy 

pub unsafe extern "C" fn fdf_dispatcher_destroy(
    dispatcher: *mut fdf_dispatcher_t,
)
Informs the runtime that |dispatcher| may be destroyed.

The dispatcher must be completely shutdown before this is called, i.e. the shutdown handler set in |fdf_dispatcher_create| has been called. It is safe to call this from that shutdown handler.

|dispatcher| must not be used after calling this function.