pub unsafe extern "C" fn fdf_dispatcher_get_current_dispatcher() -> *mut fdf_dispatcher_tExpand description
Returns the current thread’s dispatcher. This will return NULL if not called from a dispatcher managed thread.
pub unsafe extern "C" fn fdf_dispatcher_get_current_dispatcher() -> *mut fdf_dispatcher_tReturns the current thread’s dispatcher. This will return NULL if not called from a dispatcher managed thread.