fdf_dispatcher_shutdown_async

Function fdf_dispatcher_shutdown_async 

pub unsafe extern "C" fn fdf_dispatcher_shutdown_async(
    dispatcher: *mut fdf_dispatcher_t,
)
Begins shutting down the dispatcher. Shutting down is an asynchronous operation.

Once |fdf_dispatcher_shutdown_async| is called, the dispatcher will no longer accept queueing new |async_dispatcher_t| operations or |ChannelRead| callbacks.

The dispatcher will asynchronously wait for all pending |async_dispatcher_t| and |ChannelRead| callbacks to complete. Then it will serially cancel all remaining callbacks with |ZX_ERR_CANCELED| and call the shutdown handler set in |fdf_dispatcher_create|.

If the dispatcher is already shutting down or has completed shutdown, this will do nothing.