fdf_dispatcher_unregister_wake_vector

Function fdf_dispatcher_unregister_wake_vector 

pub unsafe extern "C" fn fdf_dispatcher_unregister_wake_vector(
    dispatcher: *mut fdf_dispatcher_t,
    handle: zx_handle_t,
    signals: zx_signals_t,
) -> zx_status_t
Unregisters the signals on the given handle as wake vectors.

If the |signals| provided don’t exactly match the signals that are currently registered, the delta between the two will still remain registered.

|handle| is borrowed |dispatcher| is the dispatcher that the wake vector is removed from. |signals| are the signals that will be unregistered

Errors

ZX_ERR_NOT_FOUND: The |handle| was never registered.