fdf_env_destroy_all_dispatchers

Function fdf_env_destroy_all_dispatchers 

pub unsafe extern "C" fn fdf_env_destroy_all_dispatchers()
Destroys all dispatchers in the process and blocks the current thread until each runtime dispatcher in the process is observed to have been destroyed.

This should only be used called after all dispatchers have been shutdown.

Thread requirements

This should not be called from a thread managed by the driver runtime, such as from tasks or ChannelRead callbacks.