fdf_env_dispatcher_create_with_owner

Function fdf_env_dispatcher_create_with_owner 

pub unsafe extern "C" fn fdf_env_dispatcher_create_with_owner(
    driver: *const c_void,
    options: u32,
    name: *const c_char,
    name_len: usize,
    scheduler_role: *const c_char,
    scheduler_role_len: usize,
    observer: *mut fdf_dispatcher_shutdown_observer_t,
    out_dispatcher: *mut *mut fdf_dispatcher_t,
) -> zx_status_t
Same as |fdf_dispatcher_create| but allows setting the driver owner for the dispatcher.

|driver| is an opaque pointer to the driver object. It will be used to uniquely identify the driver.