fdf_env_get_all_threads_dump

Function fdf_env_get_all_threads_dump 

pub unsafe extern "C" fn fdf_env_get_all_threads_dump(
    out_entries: *mut *mut fdf_thread_dump_entry_t,
    out_count: *mut usize,
)
Retrieves structured runtime diagnostic dumps for all threads currently spawned by the driver runtime environment.

The caller must free the returned array using |fdf_env_free_all_threads_dump|.