pub unsafe extern "C" fn fdf_env_get_scheduler_role_opts(
scheduler_role: *const c_char,
scheduler_role_len: usize,
) -> u32Expand description
Returns the currently set options for the scheduler role as a uint32_t bitmask.
|scheduler_role| is the name of the role which is passed when creating dispatchers. |scheduler_role_len| is the length of the string, without including the terminating NULL character.