fdf_env_get_thread_limit

Function fdf_env_get_thread_limit 

pub unsafe extern "C" fn fdf_env_get_thread_limit(
    scheduler_role: *const c_char,
    scheduler_role_len: usize,
) -> u32
Returns the current maximum number of threads which will be spawned for thread pool associated with the given scheduler role.

|scheduler_role| is the name of the role which is passed when creating dispatchers. |scheduler_role_len | is the length of the string, without including the terminating NULL character.