pub unsafe extern "C" fn fdf_env_register_driver_exit()Expand description
Notifies the runtime that we have exited the current driver context.
pub unsafe extern "C" fn fdf_env_register_driver_exit()Notifies the runtime that we have exited the current driver context.