pub unsafe extern "C" fn fdf_env_reset()Expand description
Resets the driver runtime to zero threads. This may only be called when there are no existing dispatchers.
pub unsafe extern "C" fn fdf_env_reset()Resets the driver runtime to zero threads. This may only be called when there are no existing dispatchers.