fdf_env_set_scheduler_role_opts

Function fdf_env_set_scheduler_role_opts 

pub unsafe extern "C" fn fdf_env_set_scheduler_role_opts(
    scheduler_role: *const c_char,
    scheduler_role_len: usize,
    options: u32,
) -> zx_status_t
Sets the options for the given scheduler role. This can be used to enforce restrictions on the kinds of dispatchers that can be created on this scheduler role.

Currently available options include:

  • FDF_SCHEDULER_ROLE_OPTION_NO_SYNC_CALLS will not allow any dispatchers on the scheduler role to be created with FDF_DISPATCHER_OPTION_ALLOW_SYNC_CALLS.

|scheduler_role| is the name of the role which is passed when creating dispatchers. |scheduler_role_len| is the length of the string, without including the terminating NULL character. |options| is the new options for the scheduler role.

Errors

ZX_ERR_INVALID_ARGS: |options| contains unknown or invalid options. ZX_ERR_NOT_SUPPORTED: |options| contains an option that wouldn’t allow a dispatcher that already exists on this scheduler role.