fdf_env_shutdown_dispatchers_async

Function fdf_env_shutdown_dispatchers_async 

pub unsafe extern "C" fn fdf_env_shutdown_dispatchers_async(
    driver: *const c_void,
    observer: *mut fdf_env_driver_shutdown_observer_t,
) -> zx_status_t
Asynchronously shuts down all dispatchers owned by |driver|. |observer| will be notified once shutdown completes. This is guaranteed to be after all the dispatcher’s shutdown observers have been called, and will be running on the thread of the final dispatcher which has been shutdown.

While a driver is shutting down, no new dispatchers can be created by the driver.

If this succeeds, you must keep the |observer| object alive until the |observer| is notified.

Errors

ZX_ERR_INVALID_ARGS: No driver matching |driver| was found.

ZX_ERR_BAD_STATE: A driver shutdown observer was already registered.