pub unsafe extern "C" fn fdf_env_start(options: u32) -> zx_status_tExpand description
Start the driver runtime. This sets up the initial thread that the dispatchers run on.
pub unsafe extern "C" fn fdf_env_start(options: u32) -> zx_status_tStart the driver runtime. This sets up the initial thread that the dispatchers run on.