pub unsafe extern "C" fn fdf_testing_create_unmanaged_dispatcher(
driver: *const c_void,
options: u32,
name: *const c_char,
name_len: usize,
observer: *mut fdf_dispatcher_shutdown_observer_t,
out_dispatcher: *mut *mut fdf_dispatcher_t,
) -> zx_status_tExpand description
Creates a dispatcher on a unmanaged thread pool. This means that there are no background threads handling this dispatcher and so it has to be ran explicitly using the various run calls. See |fdf_env_dispatcher_create_with_owner| for more information about the parameters and return value.