fdf_testing_quit

Function fdf_testing_quit 

pub unsafe extern "C" fn fdf_testing_quit()
Quits the unmanaged dispatcher pool if one has been created. Otherwise does nothing. Active invocations of |fdf_testing_run()| will eventually terminate upon completion of their current unit of work.

Subsequent calls to |fdf_testing_run()| will return immediately until |fdf_testing_reset_quit()| is called.