fdf_testing_run

Function fdf_testing_run 

pub unsafe extern "C" fn fdf_testing_run(
    deadline: zx_time_t,
    once: bool,
) -> zx_status_t
Runs the unmanaged dispatcher pool on the current thread.

Dispatches events until the |deadline| expires or it is quit. Use |ZX_TIME_INFINITE| to dispatch events indefinitely.

If |once| is true, performs a single unit of work then returns.

Returns |ZX_OK| if the dispatcher returns after one cycle. Returns |ZX_ERR_TIMED_OUT| if the deadline expired. Returns |ZX_ERR_CANCELED| if it quit. Returns |ZX_ERR_BAD_STATE| if the unmanaged dispatcher was shut down or if an unmanaged dispatcher has not been created.