fdf_testing_run_until_idle

Function fdf_testing_run_until_idle 

pub unsafe extern "C" fn fdf_testing_run_until_idle() -> zx_status_t
Runs the unmanaged dispatcher pool on the current thread. Dispatches events until there are none remaining, and then returns without waiting. This is useful for unit testing, because the behavior doesn’t depend on time.

Returns |ZX_OK| if the dispatcher reaches an idle state. Returns |ZX_ERR_CANCELED| if it is quit. Returns |ZX_ERR_BAD_STATE| if the unmanaged dispatcher was shut down or if an unmanaged dispatcher has not been created.