pub unsafe extern "C" fn fdf_testing_set_default_dispatcher(
dispatcher: *mut fdf_dispatcher_t,
) -> zx_status_tExpand description
Sets the default driver dispatcher to be returned when the current thread does not have a driver associated with it. This is useful for tests that want to attach a dispatcher to their main test thread, so that they can use objects that contains a synchronization_checker. |dispatcher| should have been created using |fdf_testing_create_unmanaged_dispatcher|, or be a nullptr to remove an existing default.
Returns |ZX_OK| if set successfully. Returns |ZX_ERR_BAD_STATE| if called from a thread managed by the driver runtime.