fdf_token_receive

Function fdf_token_receive 

pub unsafe extern "C" fn fdf_token_receive(
    token: zx_handle_t,
    handle: *mut fdf_handle_t,
) -> zx_status_t
Receives the corresponding driver handle for |token| if it has been transferred.

If |fdf_token_transfer| has been called on |token|’s pair, this will receive the driver handle that was passed to it and store it in the address pointed to by |handle|.

Transfers ownership of |token| to the runtime.

The |token| handle is consumed and is no longer available to the caller, on success or failure.

Errors

ZX_ERR_BAD_HANDLE: |token| is not a valid channel handle.

ZX_ERR_INVALID_ARGS: |handle| is NULL.

ZX_ERR_NOT_FOUND: The |token|’s pair has not been transferred before this call.