fdf_token_transfer

Function fdf_token_transfer 

pub unsafe extern "C" fn fdf_token_transfer(
    token: zx_handle_t,
    handle: fdf_handle_t,
) -> zx_status_t
Transfers the fdf handle to the owner of the channel peer of |token|.

The token transfer handler which was, or will be registered with the channel peer of |token| will receive |handle|.

Transfers ownership of |token| to the runtime, and ownership of |handle| to the driver who registered the token.

All handles are consumed and are no longer available to the caller, on success or failure.

Errors

ZX_ERR_BAD_HANDLE: |token| is not a valid channel handle, or |handle| is not a valid FDF handle.

ZX_ERR_BAD_STATE: The dispatcher is shutting down.