DriverRegistration

Struct DriverRegistration 

#[repr(C)]
pub struct DriverRegistration { pub version: u64, pub v1: DriverRegistration_driver_registration_v1, }
The |DriverRegistration| is the ABI for drivers to expose themselves to the Driver Framework. The driver is loaded in as a shared library (also referred to as a DSO), and the global symbol __fuchsia_driver_registration__ is used by the Driver Framework to locate this DriverRegistration in the driver library. The framework will use this to initiate a FIDL based connection over the driver transport into the driver.

Fields

version: u64

The version is not expected to change since the evolution of the driver APIs will happen on the FIDL side. This simply exists in case we need to evolve the initialization signature for any reason.

v1: DriverRegistration_driver_registration_v1