DriverRegistration_driver_registration_v1

Struct DriverRegistration_driver_registration_v1 

#[repr(C)]
pub struct DriverRegistration_driver_registration_v1 { pub initialize: Option<unsafe extern "C" fn(server_handle: fdf_handle_t) -> *mut c_void>, pub destroy: Option<unsafe extern "C" fn(token: *mut c_void)>, }

Fields

initialize: Option<unsafe extern "C" fn(server_handle: fdf_handle_t) -> *mut c_void>

Pointer to a function that can initialize the driver server on the |server_handle|.

Errors to initialize the driver server can be propagated by closing the |server_handle| with an epitaph, but driver start failures should use the corresponding FIDL protocol.

This function is executed on the default driver dispatcher. This dispatcher is synchronized and runs on a shared driver thread within a driver_host. The driver can access this dispatcher using |fdf_dispatcher_get_current_dispatcher()| or in C++ with |fdf::Dispatcher::GetCurrent()|. This can be stored in an |fdf::UnownedSynchronizedDispatcher| as the driver host is the owner of the dispatcher.

|server_handle| is the server end for the |fuchsia.driver.framework/Driver| protocol that the driver should begin serving on. This should be served on the driver dispatcher that this function is executed on.

The return result is a void* token that the driver framework will pass into |destroy|.

destroy: Option<unsafe extern "C" fn(token: *mut c_void)>

Pointer to a function that can free the resources that were allocated as part of |initialize|. Generally this will just be the object allocated to serve the |fuchsia.driver.framework/Driver| protocol.

This function is executed after all of the dispatchers belonging to the driver have fully been shutdown, including the default dispatcher that |initialize| was executed on.

|token| is the return result of the |initialize| function.