fdf_dispatcher_shutdown_observer

Struct fdf_dispatcher_shutdown_observer 

#[repr(C)]
pub struct fdf_dispatcher_shutdown_observer { pub handler: fdf_dispatcher_shutdown_handler_t, }
Holds context for the observer which will be called when the dispatcher’s asynchronous shutdown has completed.

After creating the dispatcher, the client is responsible for retaining this structure in memory (and unmodified) until the handler runs.

Fields

handler: fdf_dispatcher_shutdown_handler_t