fdf_env_resume_requester

Struct fdf_env_resume_requester 

#[repr(C)]
pub struct fdf_env_resume_requester { pub handler: fdf_env_resume_request, }
Holds context for the resume request which will be called when the runtime needs to be resumed.

The client is responsible for retaining this structure in memory (and unmodified) until the handler runs.

Fields

handler: fdf_env_resume_request