fdf_env_stall_scanner

Struct fdf_env_stall_scanner 

#[repr(C)]
pub struct fdf_env_stall_scanner { pub handler: fdf_env_stall_scan_begin, }
Holds context for the stall scanner which will be called when stall scanning should occur.

The client is responsible for retaining this structure in memory (and unmodified) until the handler runs.

Fields

handler: fdf_env_stall_scan_begin