#[repr(C)]pub struct fdf_token {
pub handler: fdf_token_transfer_handler_t,
}Expand description
Holds context for a registered token which is waiting for an fdf handle to be transferred.
After successfully registering the protocol, the client is responsible for retaining the structure in memory (and unmodified) until the transfer handler runs. Thereafter, this structure may be registered again or destroyed.
Fields
handler: fdf_token_transfer_handler_tTrait Implementations
impl Copy for fdf_token