pub type fdf_dispatcher_shutdown_observer_t = fdf_dispatcher_shutdown_observer;Expand description
Holds context for the observer which will be called when the dispatcher’s asynchronous shutdown has completed.
After creating the dispatcher, the client is responsible for retaining this structure in memory (and unmodified) until the handler runs.
Aliased Type
#[repr(C)]pub struct fdf_dispatcher_shutdown_observer_t {
pub handler: Option<unsafe extern "C" fn(*mut fdf_dispatcher, *mut fdf_dispatcher_shutdown_observer)>,
}Fields
handler: Option<unsafe extern "C" fn(*mut fdf_dispatcher, *mut fdf_dispatcher_shutdown_observer)>