pub type fdf_env_driver_shutdown_observer_t = fdf_env_driver_shutdown_observer;Expand description
Holds context for the observer which will be called when the asynchronous shutdown for all dispatchers owned by a driver has completed.
The client is responsible for retaining this structure in memory (and unmodified) until the handler runs.
Aliased Type
#[repr(C)]pub struct fdf_env_driver_shutdown_observer_t {
pub handler: Option<unsafe extern "C" fn(*const c_void, *mut fdf_env_driver_shutdown_observer)>,
}Fields
handler: Option<unsafe extern "C" fn(*const c_void, *mut fdf_env_driver_shutdown_observer)>