pub type fdf_env_resume_requester_t = fdf_env_resume_requester;Expand description
Holds context for the resume request which will be called when the runtime needs to be resumed.
The client is responsible for retaining this structure in memory (and unmodified) until the handler runs.
Aliased Type
#[repr(C)]pub struct fdf_env_resume_requester_t {
pub handler: Option<unsafe extern "C" fn(*mut fdf_env_resume_requester) -> i32>,
}Fields
handler: Option<unsafe extern "C" fn(*mut fdf_env_resume_requester) -> i32>