fdf_env_stall_scanner_t

Type Alias fdf_env_stall_scanner_t 

pub type fdf_env_stall_scanner_t = fdf_env_stall_scanner;
Holds context for the stall scanner which will be called when stall scanning should occur.

The client is responsible for retaining this structure in memory (and unmodified) until the handler runs.

Aliased Type

#[repr(C)]
pub struct fdf_env_stall_scanner_t { pub handler: Option<unsafe extern "C" fn(*mut fdf_env_stall_scanner, i64)>, }

Fields

handler: Option<unsafe extern "C" fn(*mut fdf_env_stall_scanner, i64)>