pub unsafe extern "C" fn fdf_arena_add_ref(arena: *mut fdf_arena_t)Expand description
Increments the reference count to the underlying runtime arena object.
This is intended mostly for use with FFIs, such as for Rust, to enable
more ergonomic use. Users in C should not need to call this, as
the reference count will be properly managed with the fdf_channel_*
and fdf_arena_drop_ref functions.
Calls to this function must be balanced by corresponding calls to
fdf_arena_drop_ref.