pub unsafe extern "C" fn fdf_arena_create(
options: u32,
tag: fdf_arena_tag_t,
out_arena: *mut *mut fdf_arena_t,
) -> zx_status_tExpand description
Creates a FDF arena for allocating memory.
|tag| provides a hint to the runtime so that it may be more efficient. For example, adjusting the size of the buffer backing the arena to the expected total size of allocations. It may also be surfaced in debug information.
Errors
ZX_ERR_INVALID_ARGS: |options| is any value other than 0.
ZX_ERR_NO_MEMORY: Failed due to a lack of memory.