pub unsafe extern "C" fn fdf_dispatcher_get_always_on_dispatcher(
dispatcher: *mut fdf_dispatcher_t,
) -> *mut fdf_dispatcher_tExpand description
Returns the always-on dispatcher interface for the given dispatcher.
The primary user of this is the driver’s fuchsia.driver.framework/Driver FIDL server which executes the driver lifecycle methods (e.g. Start, Stop).
The secondary user of this is for bindings and tasks that require execution during suspend/resume lifecycle hooks. The driver host only calls these hooks when its safe to do so (dependent elements still exist).
WARNING: Any other use will lead to execution while suspended, which may be unexpected.