pub unsafe extern "C" fn fdf_dispatcher_register_wake_vector(
dispatcher: *mut fdf_dispatcher_t,
handle: zx_handle_t,
signals: zx_signals_t,
) -> zx_status_tExpand description
Registers a wake vector. Callbacks for |signals| received on this handle while suspended, wake the driver and execute after the driver’s Resume hook, but before anything else.
The handle wait does not need to be registered before this is called. This is a sticky registration; all future waits registered with this handle will automatically inherit this wakeability.
Registration is cumulative; new signals are combined with any existing wake signals registered for this handle.
|handle| is borrowed |dispatcher| is the dispatcher that the wake vector applies to. |signals| are the signals that will wake the driver
Errors
ZX_ERR_BAD_STATE: The dispatcher is suspended.