pub unsafe extern "C" fn fdf_env_get_driver_on_tid(
tid: zx_koid_t,
out_driver: *mut *const c_void,
) -> zx_status_tExpand description
Gets the opaque pointer uniquely associated with the driver currently running on the thread identified by |tid|.
Returns the driver pointer through out parameter |out_driver|.
Errors
ZX_ERR_NOT_FOUND: If the tid did not have a driver running on it, or the tid was not able to be identified.
ZX_ERR_INVALID_ARGS: If the out_driver is not valid.