pub unsafe extern "C" fn fdf_env_register_driver_entry( driver: *const c_void, )
Notifies the runtime that we have entered a new driver context, such as via a Banjo call.
|driver| is an opaque unique identifier for the driver.