pub unsafe extern "C" fn fdf_env_scan_threads_for_stalls2() -> zx_duration_mono_tExpand description
Scans active thread pools for threads that are stalled on long running tasks and potentially spawn new threads to compensate.
Returns the amount of time the caller should wait before calling this again as a
zx_duration_mono_t. If 0 is returned, scanning should suspend until a start callback is made
via the registered stall scanner.
Thread requirements
This should not be called from a thread managed by the driver runtime, such as from tasks or ChannelRead callbacks.