pub unsafe extern "C" fn fdf_testing_reset_quit() -> zx_status_tExpand description
Resets the quit state of the unmanaged dispatcher pool so that it can be restarted using |fdf_testing_run()|.
This function must only be called when the unmanaged dispatcher pool is not running. The caller must ensure all active invocations of |fdf_testing_run()| have terminated before resetting the quit state.
Returns |ZX_OK| if the unmanaged dispatcher pool’s quit state was correctly reset. Returns |ZX_ERR_BAD_STATE| if the unmanaged dispatcher pool was shutting down or if it was currently actively running, or if an unmanaged dispatcher has not been created.