#[repr(C)]pub struct DriverRegistration {
pub version: u64,
pub v1: DriverRegistration_driver_registration_v1,
}Expand description
The |DriverRegistration| is the ABI for drivers to expose themselves to the Driver Framework.
The driver is loaded in as a shared library (also referred to as a DSO), and the global symbol
__fuchsia_driver_registration__ is used by the Driver Framework to locate this
DriverRegistration in the driver library. The framework will use this to initiate a FIDL based
connection over the driver transport into the driver.
Fields
version: u64The version is not expected to change since the evolution of the driver APIs will happen on the FIDL side. This simply exists in case we need to evolve the initialization signature for any reason.
v1: DriverRegistration_driver_registration_v1Trait Implementations
Sourceimpl Clone for DriverRegistration
impl Clone for DriverRegistration
Sourcefn clone(&self) -> DriverRegistration
fn clone(&self) -> DriverRegistration
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DriverRegistration
impl Debug for DriverRegistration
Sourceimpl Default for DriverRegistration
impl Default for DriverRegistration
Sourcefn default() -> DriverRegistration
fn default() -> DriverRegistration
Returns the “default value” for a type. Read more
impl Copy for DriverRegistration