#[repr(C)]pub struct fdf_dispatcher_shutdown_observer {
pub handler: fdf_dispatcher_shutdown_handler_t,
}Expand description
Holds context for the observer which will be called when the dispatcher’s asynchronous shutdown has completed.
After creating the dispatcher, the client is responsible for retaining this structure in memory (and unmodified) until the handler runs.
Fields
handler: fdf_dispatcher_shutdown_handler_tTrait Implementations
Sourceimpl Clone for fdf_dispatcher_shutdown_observer
impl Clone for fdf_dispatcher_shutdown_observer
Sourcefn clone(&self) -> fdf_dispatcher_shutdown_observer
fn clone(&self) -> fdf_dispatcher_shutdown_observer
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for fdf_dispatcher_shutdown_observer
impl Default for fdf_dispatcher_shutdown_observer
Sourcefn default() -> fdf_dispatcher_shutdown_observer
fn default() -> fdf_dispatcher_shutdown_observer
Returns the “default value” for a type. Read more
impl Copy for fdf_dispatcher_shutdown_observer