pub type fdf_env_suspend_completer_t = fdf_env_suspend_completer;Expand description
Holds context for the suspend completion which will be called when the driver has completed suspending.
The client is responsible for retaining this structure in memory (and unmodified) until the handler runs.
Aliased Type
#[repr(C)]pub struct fdf_env_suspend_completer_t {
pub handler: Option<unsafe extern "C" fn(*mut fdf_env_suspend_completer)>,
}Fields
handler: Option<unsafe extern "C" fn(*mut fdf_env_suspend_completer)>