pub type fdf_token_transfer_handler_t = Option<unsafe extern "C" fn(dispatcher: *mut fdf_dispatcher_t, token: *mut fdf_token_t, status: zx_status_t, handle: fdf_handle_t)>;Expand description
Handles the transfer of the fdf handle.
If |status| is ZX_OK, transfers ownership of |handle|.
The status is |ZX_OK| if the token was successfully transferred. The status is |ZX_ERR_CANCELED| if the dispatcher was shut down before the transfer was completed, or the peer token handle has been closed.
Aliased Type
pub enum fdf_token_transfer_handler_t {
None,
Some(unsafe extern "C" fn(*mut fdf_dispatcher, *mut fdf_token, i32, u32)),
}